@@ -18,6 +18,7 @@ from .commands import (
     repo_cmd,
     rollback_cmd,
     search_cmd,
+    sync_cmd,
     upgrade_cmd,
     validate_cmd,
 )
@@ -155,6 +156,7 @@ cli.add_command(install_cmd.install)
 cli.add_command(repo_cmd.repo)
 cli.add_command(rollback_cmd.rollback)
 cli.add_command(search_cmd.search)
+cli.add_command(sync_cmd.sync)
 cli.add_command(upgrade_cmd.upgrade)
 cli.add_command(validate_cmd.validate)
 
