@@ -7,6 +7,7 @@ from . import install as install_cmd
 from . import repo as repo_cmd
 from . import rollback as rollback_cmd
 from . import search as search_cmd
+from . import sync as sync_cmd
 from . import upgrade as upgrade_cmd
 from . import validate as validate_cmd
 
@@ -18,6 +19,7 @@ __all__ = [
     "repo_cmd",
     "rollback_cmd",
     "search_cmd",
+    "sync_cmd",
     "validate_cmd",
     "upgrade_cmd",
 ]
