@@ -4,10 +4,12 @@ from .git_repository import GitRepositoryHandler
 from .installer import TemplateInstaller
 from .marketplace import MarketplaceManager
 from .registry import RegistryParser
+from .sync_manager import SyncManager
 
 __all__ = [
     "GitRepositoryHandler",
     "TemplateInstaller",
     "MarketplaceManager",
     "RegistryParser",
+    "SyncManager",
 ]
